<?php

/*
Plugin Name: دیوار آتش برنامه نویس
Description: یک فایروال ساده و سبک اما قدرتمند برای وردپرس
Author: ابوالفضل قاسمی حصار
Version: 1.0.0
License: GPL2
Text Domain: developer-firewall
Author URI: https://tecparsnet.ir/
*/

if (!defined('ABSPATH')) exit;

define('TDF_URL', plugin_dir_url(__FILE__));

function tdf_save_values()
{
    if (current_user_can('manage_options')) {
        $url = add_query_arg(
            [
                'nonce' => wp_create_nonce('tdf_save_values_nonce')
            ], admin_url('admin.php?page=tdf-option-panel')
        );

        return esc_url($url);
    } else {
        return null;
    }
}

add_action('admin_init', 'tdf_save_values');

function tdf_save_wordpress_settings_values()
{
    if (isset($_POST['tdfSetWordPressSettings']) and current_user_can('manage_options') and isset($_GET['nonce']) and check_admin_referer('nonceSecurityChecker', 'nonceSecurityCheck') and wp_verify_nonce($_GET['nonce'], 'tdf_save_values_nonce')) {
        global $wpdb, $table_prefix;
        if (isset($_POST['force_ssl_admin_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'force_ssl_admin')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'force_ssl_admin')
            );
        }
        if (isset($_POST['remove_url_field_from_comments_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'remove_url_field_from_comments')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'remove_url_field_from_comments')
            );
        }
        if (isset($_POST['remove_rsd_link_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'remove_rsd_link')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'remove_rsd_link')
            );
        }
        if (isset($_POST['disallow_file_editor_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'disallow_file_editor')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'disallow_file_editor')
            );
        }
        $tdf_redirect = admin_url('admin.php?page=tdf-option-panel');
        wp_safe_redirect($tdf_redirect);
    }
}

add_action('init', 'tdf_save_wordpress_settings_values');

function tdf_save_hosting_settings_values()
{
    if (isset($_POST['tdfSetHostingSettings']) and current_user_can('manage_options') and isset($_GET['nonce']) and check_admin_referer('nonceSecurityChecker', 'nonceSecurityCheck') and wp_verify_nonce($_GET['nonce'], 'tdf_save_values_nonce')) {
        global $wpdb, $table_prefix;
        if (isset($_POST['xmlrpc_disable_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'xmlrpc_disable')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'xmlrpc_disable')
            );
        }
        if (isset($_POST['deny_directory_listing_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'deny_directory_listing')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'deny_directory_listing')
            );
        }
        if (isset($_POST['arvancloud_whitelisting_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'arvancloud_whitelisting')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'arvancloud_whitelisting')
            );
        }
        if (isset($_POST['protection_of_system_files_option'])) {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'true'),
                array('SetTDFName' => 'protection_of_system_files')
            );
        } else {
            $wpdb->update(
                $table_prefix . 'tdf',
                array('SetTDFValue' => 'false'),
                array('SetTDFName' => 'protection_of_system_files')
            );
        }
        $tdf_redirect = admin_url('admin.php?page=tdf-option-panel');
        wp_safe_redirect($tdf_redirect);
    }
}

add_action('init', 'tdf_save_hosting_settings_values');

function activate_tdf()
{
    global $table_prefix, $wpdb;
    $tdfTable = $table_prefix . 'tdf';
    if ($wpdb->get_var("show tables like '$tdfTable'") != $tdfTable) {
        $sql = "CREATE TABLE $tdfTable ( SetTDFName varchar(255) NOT NULL, SetTDFValue varchar(255), PRIMARY KEY (SetTDFName) );";
        require_once(ABSPATH . '/wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'force_ssl_admin'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'force_ssl_admin') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'force_ssl_admin',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'force_ssl_admin',
                'SetTDFValue' => 'false'
            )
        );
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'remove_url_field_from_comments'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'remove_url_field_from_comments') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'remove_url_field_from_comments',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'remove_url_field_from_comments',
                'SetTDFValue' => 'false'
            )
        );
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'remove_rsd_link'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'remove_rsd_link') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'remove_rsd_link',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'remove_rsd_link',
                'SetTDFValue' => 'false'
            )
        );
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'disallow_file_editor'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'disallow_file_editor') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'disallow_file_editor',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'disallow_file_editor',
                'SetTDFValue' => 'false'
            )
        );
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'xmlrpc_disable'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'xmlrpc_disable') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'xmlrpc_disable',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'xmlrpc_disable',
                'SetTDFValue' => 'false'
            )
        );
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'deny_directory_listing'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'deny_directory_listing') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'deny_directory_listing',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'deny_directory_listing',
                'SetTDFValue' => 'false'
            )
        );
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'arvancloud_whitelisting'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'arvancloud_whitelisting') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'arvancloud_whitelisting',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'arvancloud_whitelisting',
                'SetTDFValue' => 'false'
            )
        );
    }
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT SetTDFName FROM $tdfTable WHERE SetTDFName = 'protection_of_system_files'");
    if ($tdf_table_read_contents_search) {
        foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
            if ($tdf_table_read_content_search->SetTDFName != 'protection_of_system_files') {
                $wpdb->insert(
                    $table_prefix . 'tdf',
                    array(
                        'SetTDFName' => 'protection_of_system_files',
                        'SetTDFValue' => 'false'
                    )
                );
            }
        }
    } else {
        $wpdb->insert(
            $table_prefix . 'tdf',
            array(
                'SetTDFName' => 'protection_of_system_files',
                'SetTDFValue' => 'false'
            )
        );
    }
}

register_activation_hook(__FILE__, "activate_tdf");

function tdf_admin_menu()
{
    add_menu_page(
        __('فایروال برنامه نویس', 'developer-firewall'),
        __('فایروال برنامه نویس', 'developer-firewall'),
        'manage_options',
        'tdf-option-panel',
        'tdf_admin_page_contents',
        'dashicons-shield-alt',
        75
    );
}

add_action('admin_menu', 'tdf_admin_menu');

function tdf_check_force_ssl_admin_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'force_ssl_admin'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'force_ssl_admin' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_check_force_ssl_admin_set()) {
    define('FORCE_SSL_ADMIN', true);
}

function tdf_remove_url_field_from_comments_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'remove_url_field_from_comments'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'remove_url_field_from_comments' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_remove_url_field_from_comments_set()) {
    function tdf_remove_url_field_from_comments_remove($fields)
    {
        if (isset($fields['url']))
            unset($fields['url']);
        return $fields;
    }

    add_filter('comment_form_default_fields', 'tdf_remove_url_field_from_comments_remove');
}

function tdf_remove_rsd_link_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'remove_rsd_link'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'remove_rsd_link' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_remove_rsd_link_set()) {
    remove_action('wp_head', 'rsd_link');
}

function tdf_disallow_file_editor_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'disallow_file_editor'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'disallow_file_editor' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_disallow_file_editor_set()) {
    define('DISALLOW_FILE_EDIT', true);
}

function tdf_xmlrpc_disable_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'xmlrpc_disable'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'xmlrpc_disable' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_xmlrpc_disable_set()) {
    function tdf_xmlrpc_disable_set_rules()
    {
        $htaccess = ABSPATH . ".htaccess";
        $lines = array();
        $lines[] = "<files xmlrpc.php>";
        $lines[] = "<IfModule mod_authz_core.c>";
        $lines[] = "Require all denied";
        $lines[] = "</IfModule>";
        $lines[] = "<IfModule !mod_authz_core.c>";
        $lines[] = "Order allow,deny";
        $lines[] = "Deny from all";
        $lines[] = "</IfModule>";
        $lines[] = "</files>";
        insert_with_markers($htaccess, "Developer Firewall - #xmlrpc Disabler", $lines);
    }

    add_action('admin_init', 'tdf_xmlrpc_disable_set_rules');
    add_filter('xmlrpc_enabled', '__return_false');
}

function tdf_deny_directory_listing_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'deny_directory_listing'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'deny_directory_listing' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_deny_directory_listing_set()) {
    function tdf_deny_directory_listing_set_rules()
    {
        $htaccess = ABSPATH . ".htaccess";
        $lines = array();
        $lines[] = "Options -Indexes";
        insert_with_markers($htaccess, "Developer Firewall - #Deny Directory Listing", $lines);
    }

    add_action('admin_init', 'tdf_deny_directory_listing_set_rules');
}

function tdf_arvancloud_whitelisting_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'arvancloud_whitelisting'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'arvancloud_whitelisting' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_arvancloud_whitelisting_set()) {
    function tdf_arvancloud_whitelisting_set_rules()
    {
        $htaccess = ABSPATH . ".htaccess";
        $lines = array();
        $lines[] = "Allow from 46.224.2.32/29";
        $lines[] = "Allow from 2.146.0.0/28";
        $lines[] = "Allow from 92.114.16.80/28";
        $lines[] = "Allow from 79.175.138.128/29";
        $lines[] = "Allow from 185.143.232.0/22";
        $lines[] = "Allow from 89.187.178.96/29";
        $lines[] = "Allow from 89.187.169.88/29";
        $lines[] = "Allow from 195.181.173.128/29";
        $lines[] = "Allow from 185.152.67.56/29";
        $lines[] = "Allow from 185.246.211.64/27";
        $lines[] = "Allow from 89.187.175.136/29";
        $lines[] = "Allow from 83.121.255.40/31";
        $lines[] = "Allow from 164.138.128.28/31";
        $lines[] = "Allow from 83.123.255.56/31";
        $lines[] = "Allow from 188.229.116.16/29";
        $lines[] = "Allow from 198.13.38.112/28";
        $lines[] = "Allow from 149.28.160.0/28";
        $lines[] = "Allow from 94.182.182.28/30";
        $lines[] = "Allow from 185.17.115.176/30";
        $lines[] = "Allow from 89.187.163.144/28";
        $lines[] = "Allow from 91.193.5.216/29";
        $lines[] = "Allow from 188.241.176.160/29";
        $lines[] = "Allow from 193.239.86.24/29";
        $lines[] = "Allow from 176.125.231.56/29";
        $lines[] = "Allow from 84.252.94.0/29";
        $lines[] = "Allow from 91.219.214.48/29";
        $lines[] = "Allow from 193.29.105.128/29";
        $lines[] = "Allow from 89.45.48.8/29";
        $lines[] = "Allow from 185.208.180.88/29";
        $lines[] = "Allow from 103.104.74.48/30";
        $lines[] = "Allow from 103.11.153.208/30";
        $lines[] = "Allow from 89.38.225.56/30";
        $lines[] = "Allow from 213.183.32.88/29";
        $lines[] = "Allow from 185.104.184.72/30";
        $lines[] = "Allow from 5.213.255.36/31";
        $lines[] = "Allow from 109.200.214.248/32";
        $lines[] = "Allow from 5.200.14.8/32";
        $lines[] = "Allow from 188.122.68.224/32";
        $lines[] = "Allow from 213.179.211.32/32";
        $lines[] = "Allow from 162.244.52.120/32";
        $lines[] = "Allow from 213.179.201.192/32";
        $lines[] = "Allow from 213.179.217.16/32";
        $lines[] = "Allow from 188.122.80.240/32";
        $lines[] = "Allow from 103.194.164.24/32";
        $lines[] = "Allow from 188.122.83.176/32";
        $lines[] = "Allow from 188.122.78.136/32";
        $lines[] = "Allow from 138.128.141.16/32";
        $lines[] = "Allow from 185.50.105.136/32";
        $lines[] = "Allow from 213.179.197.16/32";
        $lines[] = "Allow from 213.179.213.16/32";
        $lines[] = "Allow from 185.179.201.192/32";
        $lines[] = "Allow from 138.128.139.144/32";
        $lines[] = "Allow from 43.239.139.192/32";
        insert_with_markers($htaccess, "Developer Firewall - #ArvanCloud IPS Whitelisting", $lines);
    }

    add_action('admin_init', 'tdf_arvancloud_whitelisting_set_rules');
}

function tdf_protection_of_system_files_set()
{
    global $wpdb, $table_prefix;
    $tdfTable = $table_prefix . 'tdf';
    $tdf_table_read_contents_search = $wpdb->get_results("SELECT * FROM $tdfTable WHERE SetTDFName = 'protection_of_system_files'");
    foreach ($tdf_table_read_contents_search as $tdf_table_read_content_search) {
        if ($tdf_table_read_content_search->SetTDFName == 'protection_of_system_files' and $tdf_table_read_content_search->SetTDFValue == 'true') {
            return true;
        } else {
            return false;
        }
    }
}

if (tdf_protection_of_system_files_set()) {
    function tdf_protection_of_system_files_set_rules()
    {
        $htaccess = ABSPATH . ".htaccess";
        $lines = array();
        $lines[] = "<files .htaccess>";
        $lines[] = "<IfModule mod_authz_core.c>";
        $lines[] = "Require all denied";
        $lines[] = "</IfModule>";
        $lines[] = "<IfModule !mod_authz_core.c>";
        $lines[] = "Order allow,deny";
        $lines[] = "Deny from all";
        $lines[] = "</IfModule>";
        $lines[] = "</files>";
        $lines[] = "<files readme.html>";
        $lines[] = "<IfModule mod_authz_core.c>";
        $lines[] = "Require all denied";
        $lines[] = "</IfModule>";
        $lines[] = "<IfModule !mod_authz_core.c>";
        $lines[] = "Order allow,deny";
        $lines[] = "Deny from all";
        $lines[] = "</IfModule>";
        $lines[] = "</files>";
        $lines[] = "<files readme.txt>";
        $lines[] = "<IfModule mod_authz_core.c>";
        $lines[] = "Require all denied";
        $lines[] = "</IfModule>";
        $lines[] = "<IfModule !mod_authz_core.c>";
        $lines[] = "Order allow,deny";
        $lines[] = "Deny from all";
        $lines[] = "</IfModule>";
        $lines[] = "</files>";
        $lines[] = "<files wp-config.php>";
        $lines[] = "<IfModule mod_authz_core.c>";
        $lines[] = "Require all denied";
        $lines[] = "</IfModule>";
        $lines[] = "<IfModule !mod_authz_core.c>";
        $lines[] = "Order allow,deny";
        $lines[] = "Deny from all";
        $lines[] = "</IfModule>";
        $lines[] = "</files>";
        $lines[] = "<IfModule mod_rewrite.c>";
        $lines[] = "RewriteEngine On";
        $lines[] = "RewriteRule ^wp-admin/install\.php$ - [F]";
        $lines[] = "RewriteRule ^wp-admin/includes/ - [F]";
        $lines[] = "RewriteRule !^wp-includes/ - [S=3]";
        $lines[] = "RewriteRule ^wp-includes/[^/]+\.php$ - [F]";
        $lines[] = "RewriteRule ^wp-includes/js/tinymce/langs/.+\.php - [F]";
        $lines[] = "RewriteRule ^wp-includes/theme-compat/ - [F]";
        $lines[] = "RewriteCond %{REQUEST_FILENAME} -f";
        $lines[] = "RewriteRule (^|.*/)\.(git|svn)/.* - [F]";
        $lines[] = "</IfModule>";
        insert_with_markers($htaccess, "Developer Firewall - #Protection of System Files Set Rules", $lines);
    }

    add_action('admin_init', 'tdf_protection_of_system_files_set_rules');
}

function tdf_admin_page_contents()
{
    ?>
    <style>
        @font-face {
            font-family: "IRANYekanDeveloperFirewall";
            src: url(<?php echo TDF_URL . "/assets/fonts/IRANYekanWebMedium.woff"; ?>);
        }

        #tdf_option_panel {
            width: 99%;
            height: 550px;
            background-color: #FFCC00;
            margin-top: 20px;
            border-radius: 10px;
            font-family: "IRANYekanDeveloperFirewall", Tahoma, sans-serif !important;
        }

        #tdf_option_panel * {
            font-family: "IRANYekanDeveloperFirewall", Tahoma, sans-serif !important;
        }

        #tdf_option_panel_main_sidebar {
            width: 20%;
            height: 550px;
            background-color: #ECF0F1;
            border-radius: 0 10px 10px 0;
            float: right;
        }

        #tdf_option_panel_main_sidebar > ul {
            width: 100%;
            height: 550px;
            margin: 0;
            padding: 0;
            border-radius: 0 10px 10px 0;
        }

        #tdf_option_panel_main_sidebar > ul > h1 {
            width: 100%;
            font-size: 14pt;
            margin: 0;
            padding: 20px 0;
            text-align: center;
            background-color: #FFCC00;
            border-radius: 0 10px 0 0;
        }

        #tdf_option_panel_main_sidebar > ul > li {
            width: 90%;
            height: 45px;
            margin: 3px auto;
            padding: 0 5%;
            background-color: #FDFDFD;
            transition: all 350ms ease-in-out;
            text-align: right;
            line-height: 45px;
            font-size: 12pt;
            cursor: pointer;
        }

        #tdf_option_panel_main_sidebar > ul > li:hover {
            background-color: #FFCC00;
        }

        #tdf_option_panel_main_sidebar > ul > li:first-child {
            margin-top: 20px;
        }

        .SectionSpace {
            width: 78%;
            height: 530px;
            margin-top: 10px;
            background-color: #ECF0F1;
            border-radius: 5px;
            margin-left: 1%;
            position: relative;
            float: left;
        }

        .SectionSpace > h2 {
            width: 98%;
            background-color: #FDFDFD;
            margin: 0;
            padding: 25px 2% 25px 0;
            border-radius: 5px 5px 0 0;
        }

        .SectionSpace > form {
            margin: 0;
            padding: 20px;
        }

        .SectionSpace > form > label {
            padding: 10px;
            border-radius: 5px;
            background-color: #FDFDFD;
        }

        .SectionSpace > form > input[type="submit"] {
            width: 98%;
            height: 35px;
            position: absolute;
            border: none;
            background-color: #FFCC00;
            transition: all 350ms ease-in-out;
            bottom: 10px;
            right: 1%;
            border-radius: 5px;
            cursor: pointer;
        }

        .SectionSpace > form > input[type="submit"]:hover {
            background-color: #FDFDFD;
        }

        #homeSectionSpace {
            display: block;
            position: relative;
        }

        #homeSectionSpace > #tdfHomeShow {
            width: 100%;
        }

        #homeSectionSpace > #tdfHomeShow > div:nth-child(2) {
            width: 90%;
            height: 180px;
            position: absolute;
            bottom: 0;
            right: 0;
            padding: 10px 5%;
            background-color: #FDFDFD;
            border-radius: 0 0 5px 5px;
        }

        #homeSectionSpace > #tdfHomeShow > div > #tdfHomeShowMiniTexts {
            width: 40%;
            float: right;
        }

        #homeSectionSpace > #tdfHomeShow > div > #tdfHomeShowMiniTexts > p {
            font-size: 11pt;
            background-color: #FFCC00;
            padding: 20px;
            border-radius: 5px;
        }

        #WordPressSectionSpace {
            display: none;
        }

        #WordPressSectionSpace > form > label:nth-child(2) {
            margin-right: 10px;
        }

        #WordPressSectionSpace > form > label:nth-child(3) {
            margin-right: 10px;
        }

        #WordPressSectionSpace > form > label:nth-child(4) {
            line-height: 80px;
        }

        #HostingSectionSpace {
            display: none;
        }

        #HostingSectionSpace > form > label:nth-child(2) {
            margin-right: 10px;
        }

        #HostingSectionSpace > form > label:nth-child(3) {
            margin-right: 10px;
        }

        #HostingSectionSpace > form > label:nth-child(4) {
            line-height: 80px;
        }

        #AboutUsSectionSpace {
            display: none;
        }

        #AboutUsSectionSpace > #tdfAboutUsShow {
            width: 100%;
        }

        #AboutUsSectionSpace > #tdfAboutUsShow > h3 {
            width: 100%;
            background-color: #FDFDFD;
            margin: 5px 0 0;
            text-align: center;
            padding: 35px 0;
        }

        #AboutUsSectionSpace > #tdfAboutUsShow > h3:first-child {
            margin-top: 75px;
        }
    </style>
    <div id="tdf_option_panel">
        <aside id="tdf_option_panel_main_sidebar">
            <ul>
                <h1>فایروال برنامه نویس</h1>
                <li id="homeMenu">پیشخوان</li>
                <li id="WordPressMenu">تنظیمات وردپرس</li>
                <li id="HostingMenu">تنظیمات هاستینگ</li>
                <li id="AboutUsMenu">درباره برنامه نویس</li>
            </ul>
        </aside>
        <section id="homeSectionSpace" class="SectionSpace">
            <h2>پیشخوان</h2>
            <div id="tdfHomeShow">
                <div></div>
                <div>
                    <div id="tdfHomeShowMiniTexts">
                        <p>افزونه فایروال برنامه نویس یک سیستم امنیتی خودکار و خود تنظیم مناسب برای وب سایت های ایرانی
                            هست،
                            کافیست تنظیمات موردنظر خود را از پنل تنظیمات انتخاب نمایید تا امنیت وب سایت شما تامین
                            بشه</p>
                    </div>
                </div>
            </div>
        </section>
        <section id="WordPressSectionSpace" class="SectionSpace">
            <h2>تنظیمات وردپرس</h2>
            <form action="<?php echo tdf_save_values(); ?>" method="post">
                <label for="force_ssl_admin_option">اجباری کردن SSL در پیشخوان وردپرس
                    <input id="force_ssl_admin_option"
                           type="checkbox" <?php if (tdf_check_force_ssl_admin_set() == true) {
                        echo 'checked';
                    } ?> name="force_ssl_admin_option">
                </label>
                <label for="remove_url_field_from_comments_option">غیرفعال کردن فیلد آدرس وب سایت نظرات
                    <input id="remove_url_field_from_comments_option"
                           type="checkbox" <?php if (tdf_remove_url_field_from_comments_set() == true) {
                        echo 'checked';
                    } ?> name="remove_url_field_from_comments_option">
                </label>
                <label for="remove_rsd_link_option">حذف لینک و سربرگ RSD از وردپرس
                    <input id="remove_rsd_link_option" type="checkbox" <?php if (tdf_remove_rsd_link_set() == true) {
                        echo 'checked';
                    } ?> name="remove_rsd_link_option">
                </label>
                <label for="disallow_file_editor_option">غیرفعالسازی ویرایشگر قالب و افزونه ها وردپرس
                    <input id="disallow_file_editor_option"
                           type="checkbox" <?php if (tdf_disallow_file_editor_set() == true) {
                        echo 'checked';
                    } ?> name="disallow_file_editor_option">
                </label>
                <?php wp_nonce_field('nonceSecurityChecker', 'nonceSecurityCheck'); ?>
                <input type="submit" name="tdfSetWordPressSettings" value="ثبت و ذخیره تنظیمات امنیتی">
            </form>
        </section>
        <section id="HostingSectionSpace" class="SectionSpace">
            <h2>تنظیمات هاستینگ</h2>
            <form action="<?php echo tdf_save_values(); ?>" method="post">
                <label for="xmlrpc_disable_option">غیرفعال سازی ماژول XML-RPC در سرور
                    <input id="xmlrpc_disable_option" type="checkbox" <?php if (tdf_xmlrpc_disable_set() == true) {
                        echo 'checked';
                    } ?> name="xmlrpc_disable_option">
                </label>
                <label for="deny_directory_listing_option">غیرفعالسازی نمایش دایرکتوری وب سرور
                    <input id="deny_directory_listing_option"
                           type="checkbox" <?php if (tdf_deny_directory_listing_set() == true) {
                        echo 'checked';
                    } ?> name="deny_directory_listing_option">
                </label>
                <label for="arvancloud_whitelisting_option">وایت لیست سازی آی پی های CDN ابرآروان
                    <input id="arvancloud_whitelisting_option"
                           type="checkbox" <?php if (tdf_arvancloud_whitelisting_set() == true) {
                        echo 'checked';
                    } ?> name="arvancloud_whitelisting_option">
                </label>
                <label for="protection_of_system_files_option">حفاظت از پرونده های سیستم وردپرس در سرور
                    <input id="protection_of_system_files_option"
                           type="checkbox" <?php if (tdf_protection_of_system_files_set() == true) {
                        echo 'checked';
                    } ?> name="protection_of_system_files_option">
                </label>
                <?php wp_nonce_field('nonceSecurityChecker', 'nonceSecurityCheck'); ?>
                <input type="submit" name="tdfSetHostingSettings" value="ثبت و ذخیره تنظیمات امنیتی">
            </form>
        </section>
        <section id="AboutUsSectionSpace" class="SectionSpace">
            <h2>درباره برنامه نویس</h2>
            <div id="tdfAboutUsShow">
                <h3>ابوالفضل قاسمی حصار</h3>
                <h3>soozanfoolad9@gmail.com</h3>
                <h3>tecparsnet.ir</h3>
            </div>
        </section>
    </div>
    <script>
        jQuery("#homeMenu").click(function () {
            jQuery("#homeSectionSpace").show();
            jQuery("#WordPressSectionSpace").hide();
            jQuery("#HostingSectionSpace").hide();
            jQuery("#AboutUsSectionSpace").hide();
        })
        jQuery("#WordPressMenu").click(function () {
            jQuery("#homeSectionSpace").hide();
            jQuery("#WordPressSectionSpace").show();
            jQuery("#HostingSectionSpace").hide();
            jQuery("#AboutUsSectionSpace").hide();
        })
        jQuery("#HostingMenu").click(function () {
            jQuery("#homeSectionSpace").hide();
            jQuery("#WordPressSectionSpace").hide();
            jQuery("#HostingSectionSpace").show();
            jQuery("#AboutUsSectionSpace").hide();
        })
        jQuery("#AboutUsMenu").click(function () {
            jQuery("#homeSectionSpace").hide();
            jQuery("#WordPressSectionSpace").hide();
            jQuery("#HostingSectionSpace").hide();
            jQuery("#AboutUsSectionSpace").show();
        })
    </script>
    <?php
}